@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include <math.h>
@@ -86,23 +86,11 @@ load_pixbufs (void)
 }
 
 /* Expose callback for the drawing area */
-static gint
-expose_cb (GtkWidget *widget, GdkEventExpose *event, gpointer data)
+static gboolean
+draw_cb (GtkWidget *widget, cairo_t *cr, gpointer data)
 {
-	guchar *pixels;
-	int rowstride;
-
-	rowstride = gdk_pixbuf_get_rowstride (frame);
-
-	pixels = gdk_pixbuf_get_pixels (frame) + rowstride * event->area.y + event->area.x * 3;
-		  
-	gdk_draw_rgb_image_dithalign (widget->window,
-				      widget->style->black_gc,
-				      event->area.x, event->area.y,
-				      event->area.width, event->area.height,
-				      GDK_RGB_DITHER_NORMAL,
-				      pixels, rowstride,
-				      event->area.x, event->area.y);
+        gdk_cairo_set_source_pixbuf (cr, frame, 0, 0);
+        cairo_paint (cr);
 
 	return TRUE;
 }
@@ -185,9 +173,9 @@ static guint timeout_id;
 
 /* Destroy handler for the window */
 static void
-destroy_cb (GtkObject *object, gpointer data)
+destroy_cb (GObject *object, gpointer data)
 {
-	gtk_timeout_remove (timeout_id);
+	g_source_remove (timeout_id);
 	timeout_id = 0;
 
 	gtk_main_quit ();
@@ -220,12 +208,12 @@ main (int argc, char **argv)
 
 	da = gtk_drawing_area_new ();
 
-	g_signal_connect (da, "expose_event",
-			  G_CALLBACK (expose_cb), NULL);
+	g_signal_connect (da, "draw",
+			  G_CALLBACK (draw_cb), NULL);
 
 	gtk_container_add (GTK_CONTAINER (window), da);
 
-	timeout_id = gtk_timeout_add (FRAME_DELAY, timeout, NULL);
+	timeout_id = gdk_threads_add_timeout (FRAME_DELAY, timeout, NULL);
 
 	gtk_widget_show_all (window);
 	gtk_main ();
