@@ -262,6 +262,10 @@ void            _gtk_cell_renderer_calc_offset    (GtkCellRenderer      *cell,
                                                    gint                 *x_offset,
                                                    gint                 *y_offset);
 
+GtkStateFlags   gtk_cell_renderer_get_state       (GtkCellRenderer      *cell,
+                                                   GtkWidget            *widget,
+                                                   GtkCellRendererState  cell_state);
+
 G_END_DECLS
 
 #endif /* __GTK_CELL_RENDERER_H__ */
