@@ -52,7 +52,8 @@ enum {
   PROP_ERROR_COLOR,
   PROP_WARNING_COLOR,
   PROP_SUCCESS_COLOR,
-  PROP_PADDING
+  PROP_PADDING,
+  PROP_ICON_SIZE
 };
 
 struct _GtkTrayIconPrivate
@@ -66,6 +67,7 @@ struct _GtkTrayIconPrivate
   Atom visual_atom;
   Atom colors_atom;
   Atom padding_atom;
+  Atom icon_size_atom;
   Window manager_window;
   GdkVisual *manager_visual;
   gboolean manager_visual_rgba;
@@ -76,6 +78,7 @@ struct _GtkTrayIconPrivate
   GdkColor warning_color;
   GdkColor success_color;
   gint padding;
+  gint icon_size;
 };
 
 static void gtk_tray_icon_constructed   (GObject     *object);
@@ -170,6 +173,16 @@ gtk_tray_icon_class_init (GtkTrayIconClass *class)
                                                      0,
 						     GTK_PARAM_READABLE));
 
+  g_object_class_install_property (gobject_class,
+				   PROP_ICON_SIZE,
+				   g_param_spec_int ("icon-size",
+						     P_("Icon Size"),
+						     P_("The pixel size that icons should be forced to, or zero"),
+						     0,
+                                                     G_MAXINT,
+                                                     0,
+						     GTK_PARAM_READABLE));
+
   g_type_class_add_private (class, sizeof (GtkTrayIconPrivate));
 }
 
@@ -194,6 +207,7 @@ gtk_tray_icon_init (GtkTrayIcon *icon)
   icon->priv->success_color.green = 0x9a00;
   icon->priv->success_color.blue  = 0x0600;
   icon->priv->padding = 0;
+  icon->priv->icon_size = 0;
 
   gtk_widget_set_app_paintable (GTK_WIDGET (icon), TRUE);
   gtk_widget_add_events (GTK_WIDGET (icon), GDK_PROPERTY_CHANGE_MASK);
@@ -239,6 +253,10 @@ gtk_tray_icon_constructed (GObject *object)
 					 "_NET_SYSTEM_TRAY_PADDING",
 					 False);
 
+  icon->priv->icon_size_atom = XInternAtom (xdisplay,
+                                            "_NET_SYSTEM_TRAY_ICON_SIZE",
+                                            False);
+
   /* Add a root window filter so that we get changes on MANAGER */
   gdk_window_add_filter (root_window,
 			 gtk_tray_icon_manager_filter, icon);
@@ -307,6 +325,9 @@ gtk_tray_icon_get_property (GObject    *object,
     case PROP_PADDING:
       g_value_set_int (value, icon->priv->padding);
       break;
+    case PROP_ICON_SIZE:
+      g_value_set_int (value, icon->priv->icon_size);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -635,6 +656,55 @@ gtk_tray_icon_get_padding_property (GtkTrayIcon *icon)
     XFree (prop.prop);
 }
 
+static void
+gtk_tray_icon_get_icon_size_property (GtkTrayIcon *icon)
+{
+  GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (icon));
+  GdkDisplay *display = gdk_screen_get_display (screen);
+  Display *xdisplay = GDK_DISPLAY_XDISPLAY (display);
+
+  Atom type;
+  int format;
+  union {
+	gulong *prop;
+	guchar *prop_ch;
+  } prop = { NULL };
+  gulong nitems;
+  gulong bytes_after;
+  int error, result;
+
+  g_assert (icon->priv->manager_window != None);
+
+  gdk_error_trap_push ();
+  type = None;
+  result = XGetWindowProperty (xdisplay,
+			       icon->priv->manager_window,
+			       icon->priv->icon_size_atom,
+			       0, G_MAXLONG, FALSE,
+			       XA_CARDINAL,
+			       &type, &format, &nitems,
+			       &bytes_after, &(prop.prop_ch));
+  error = gdk_error_trap_pop ();
+
+  if (!error && result == Success &&
+      type == XA_CARDINAL && nitems == 1 && format == 32)
+    {
+      gint icon_size;
+
+      icon_size = prop.prop[0];
+
+      if (icon->priv->icon_size != icon_size)
+	{
+	  icon->priv->icon_size = icon_size;
+
+	  g_object_notify (G_OBJECT (icon), "icon-size");
+	}
+    }
+
+  if (type != None)
+    XFree (prop.prop);
+}
+
 static GdkFilterReturn
 gtk_tray_icon_manager_filter (GdkXEvent *xevent,
 			      GdkEvent  *event,
@@ -675,6 +745,11 @@ gtk_tray_icon_manager_filter (GdkXEvent *xevent,
         {
           gtk_tray_icon_get_padding_property (icon);
         }
+      else if (xev->xany.type == PropertyNotify &&
+               xev->xproperty.atom == icon->priv->icon_size_atom)
+        {
+          gtk_tray_icon_get_icon_size_property (icon);
+        }
       else if (xev->xany.type == DestroyNotify)
 	{
           GTK_NOTE (PLUGSOCKET,
@@ -784,6 +859,7 @@ gtk_tray_icon_update_manager_window (GtkTrayIcon *icon)
       gtk_tray_icon_get_visual_property (icon);
       gtk_tray_icon_get_colors_property (icon);
       gtk_tray_icon_get_padding_property (icon);
+      gtk_tray_icon_get_icon_size_property (icon);
 
       if (gtk_widget_get_realized (GTK_WIDGET (icon)))
 	{
@@ -1015,3 +1091,11 @@ _gtk_tray_icon_get_padding (GtkTrayIcon *icon)
 
   return icon->priv->padding;
 }
+
+gint
+_gtk_tray_icon_get_icon_size (GtkTrayIcon *icon)
+{
+  g_return_val_if_fail (GTK_IS_TRAY_ICON (icon), 0);
+
+  return icon->priv->icon_size;
+}
